4.2. Application-independent attributes
The following attributes are obtained from the respective driver and
available to all components that the driver uses. In the case of
CESM/NorESM, the driver ingests these attributes from the
nuopc.runconfig file. In the case of UFS, the UFS driver ingests
these attributes from the ufs.configure file. The list of
attributes below are separated into application independent attributes
and at this time additional attributes required by CESM. There are no
UFS-specific attributes required by the UFS application.
4.2.1. General
coupling_mode (required)
The coupling_mode attribute determines which
esmFlds_exchange_xxx_mod.F90is used by CMEPS and is also leveraged in some of the custom calculations in theprepmodules.The currently supported values for
coupling_modearecesm,noresm,ufs.(frac,nfrac).(aoflux), andhafs.
4.2.2. Scalar attributes
- ScalarFieldCount
The maximum number of scalars that are going to be communicated between the mediator and a component. Currently scalar values are put into a field bundle that only contains an undistributed dimension equal to the size of
ScalarFieldCountand communicated between the component and the mediator on the main task of each component.- ScalarFieldName (required)
This is the name of the scalar field bundle. By default it is
cpl_scalars.- ScalarFieldIdxGridNX, ScalarFieldIdxGridNY (required)
The global number of longitude and latitude points. For unstructured grids:
ScalarFieldIdxGridNY = 1 ScalarFieldIdxGridNX = global size of mesh
For cases where
ScalarFieldIdxGridNYis not 1, this scalar data is needed by the mediator for the history output.- ScalarFieldIdxNextSwCday (optional)
Send by the atmosphere component to specify the calendar day of its next short wave computation. This is subsequently used by other components (e.g. cesm-land and sea-ice) in determining the zenith angle for its albedo calculation. It is also used in the mediator routine
med_phases_ocnalb_mod.F90to determine the zenith angle in the ocean albedo calculation.
4.2.3. Mediator history and restart attributes
- history_option, history_n (required)
Determines the write frequency for a mediator history file (see mediator history writes).
- restart_option, restart_n (required)
Determines the write frequency for a mediator restart file (see mediator restart writes).
- read_restart (required)
Determines if a mediator restart file is read in.